"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
var _interopRequireWildcard3 = require("@babel/runtime/helpers/interopRequireWildcard").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = customSearch;
var _interopRequireWildcard2 = _interopRequireDefault(require("@babel/runtime/helpers/interopRequireWildcard"));
var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));
var _react = _interopRequireWildcard3(require("react"));
var _search = require("@codemirror/search");
var _TextInput = require("@instructure/ui-text-input/lib/TextInput");
var _IconButton = require("@instructure/ui-buttons/lib/IconButton");
var _IconArrowOpenDownLine = require("@instructure/ui-icons/lib/IconArrowOpenDownLine.js");
var _IconArrowOpenUpLine2 = require("@instructure/ui-icons/lib/IconArrowOpenUpLine.js");
var _IconSearchLine2 = require("@instructure/ui-icons/lib/IconSearchLine.js");
var _reactDom = _interopRequireDefault(require("react-dom"));
var _IconSearchLine, _IconArrowOpenDownLin, _IconArrowOpenUpLine;
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2015 - present Instructure, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
function SearchPanel({
  view,
  searchConfig
}) {
  const _useState = (0, _react.useState)(''),
    _useState2 = (0, _slicedToArray2.default)(_useState, 2),
    searchQueryStr = _useState2[0],
    setSearchQueryStr = _useState2[1];
  const handleChange = (_e, value) => {
    setSearchQueryStr(value);
    handleHighlightSearch(value);
  };
  const handleHighlightSearch = searchStr => {
    view.dispatch({
      effects: _search.setSearchQuery.of(new _search.SearchQuery({
        search: searchStr
      }))
    });
  };
  const handleKeyDown = e => {
    if (e.key !== 'Enter') return;
    if (!e.shiftKey) handleFindNext();else handleFindPrev();
  };
  const handleKeyUp = e => {
    if (e.key !== 'Escape') return;
    (0, _search.closeSearchPanel)(view);
  };
  const handleFindNext = () => {
    handleHighlightSearch(searchQueryStr);
    (0, _search.findNext)(view);
  };
  const handleFindPrev = () => {
    handleHighlightSearch(searchQueryStr);
    (0, _search.findPrevious)(view);
  };
  return /*#__PURE__*/_react.default.createElement(_TextInput.TextInput, {
    renderLabel: "",
    inputRef: r => {
      setTimeout(() => r === null || r === void 0 ? void 0 : r.focus(), 0);
    },
    size: "small",
    display: "inline-block",
    width: "20rem",
    placeholder: searchConfig.placeholder,
    onChange: handleChange,
    onKeyDown: handleKeyDown,
    onKeyUp: handleKeyUp,
    renderBeforeInput: _IconSearchLine || (_IconSearchLine = /*#__PURE__*/_react.default.createElement(_IconSearchLine2.IconSearchLine, {
      size: "x-small"
    })),
    renderAfterInput: /*#__PURE__*/_react.default.createElement("span", null, /*#__PURE__*/_react.default.createElement(_IconButton.IconButton, {
      size: "small",
      withBorder: false,
      withBackground: false,
      onClick: handleFindNext,
      screenReaderLabel: searchConfig.nextResultLabel
    }, _IconArrowOpenDownLin || (_IconArrowOpenDownLin = /*#__PURE__*/_react.default.createElement(_IconArrowOpenDownLine.IconArrowOpenDownLine, null))), /*#__PURE__*/_react.default.createElement(_IconButton.IconButton, {
      size: "small",
      withBorder: false,
      withBackground: false,
      onClick: handleFindPrev,
      screenReaderLabel: searchConfig.prevResultLabel
    }, _IconArrowOpenUpLine || (_IconArrowOpenUpLine = /*#__PURE__*/_react.default.createElement(_IconArrowOpenUpLine2.IconArrowOpenUpLine, null))))
  });
}
function customSearch(searchConfig) {
  return searchConfig ? (0, _search.search)({
    createPanel: view => {
      var _SearchPanel;
      const dom = document.createElement('div');
      dom.style.padding = '8px';
      const reactVersionMajor = Number(_react.default.version.split('.')[0]);
      if (reactVersionMajor >= 18) {
        const module = 'react-dom/client';
        // webpack tries to evaluate imports compile time which would lead to an error on older react versions
        // Vite errors out during build in React v16/17
        (specifier => new Promise(r => r(`${specifier}`)).then(s => (0, _interopRequireWildcard2.default)(require(s))))(/* webpackIgnore: true */ /* @vite-ignore */module).then(r => {
          const root = r.createRoot(dom);
          root.render(_SearchPanel || (_SearchPanel = /*#__PURE__*/_react.default.createElement(SearchPanel, {
            view: view,
            searchConfig: searchConfig
          })));
        }).catch(e => {});
      } else {
        _reactDom.default.render(/*#__PURE__*/_react.default.createElement(SearchPanel, {
          view: view,
          searchConfig: searchConfig
        }), dom);
      }
      return {
        dom
      };
    }
  }) : [];
}